#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-JrtRcqFeG4l24QOQw5fb1t
key:                  persistent-test-2.13.1.3-JrtRcqFeG4l24QOQw5fb1t
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  3cecca80741ce8be47524e46f9aa24a9
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-JrtRcqFeG4l24QOQw5fb1t
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-KKpj9xjK5s16FHurgbycnn
    aeson-2.2.2.0-I4TBg1DJhLsFbcwgkuafNJ base-4.18.2.1
    blaze-html-0.9.2.0-C3tYv95GKuhLnKAx05hjcw bytestring-0.11.5.3
    conduit-1.3.6.1-EcgUgvtEMLyH8F5dS2Qay5 containers-0.6.7
    exceptions-0.10.7 hspec-2.11.6-BbEEg2y8GOLI4Xv79thZsm
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-6rhAeoExtmSLOw1wQVhqdJ
    monad-control-1.0.3.1-3wJVM6Vqe3nBBeReQrJrrE
    monad-logger-0.3.42-428lkTjoXhEB0C6k6jpI7k mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-C6G6kwanc0M1lQZcg04mvO
    quickcheck-instances-0.3.33-86qpXMbLHVkH32N52mdhuQ
    random-1.2.1.3-LwaPdrRXsBLJH2A1U2p1p
    resourcet-1.2.6-Eiin09vl6BXE97MJ850Zwl text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-CJb1zh6JrctC8ZfZ2Bomrp
    unliftio-0.2.25.1-2kLBdqoZ53hQro8XfzgjZ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

